Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(53)

Unified Diff: src/ic.h

Issue 8366036: Handlify call cases for pre-monomorphic, normal, and miss. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ia32/ic-ia32.cc ('k') | src/mips/ic-mips.cc » ('j') | src/stub-cache.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ic.h
diff --git a/src/ic.h b/src/ic.h
index d707b72059599663414fb8a459725ee7db674f94..009d6a1ac45ff3b0bf39ac795b0f67d30f126c34 100644
--- a/src/ic.h
+++ b/src/ic.h
@@ -236,12 +236,15 @@ class CallICBase: public IC {
static void Clear(Address address, Code* target);
// Platform-specific generation of misses for call and keyed call.
static void GenerateMiss(MacroAssembler* masm,
int argc,
IC::UtilityId id,
Code::ExtraICState extra_state);
+ static void GenerateNormal(MacroAssembler* masm, int argc);
+
Code::Kind kind_;
friend class IC;
@@ -271,7 +274,10 @@ class CallIC: public CallICBase {
int argc,
Code::ExtraICState extra_ic_state);
- static void GenerateNormal(MacroAssembler* masm, int argc);
+ static void GenerateNormal(MacroAssembler* masm, int argc) {
+ CallICBase::GenerateNormal(masm, argc);
+ GenerateMiss(masm, argc, Code::kNoExtraICState);
+ }
};
« no previous file with comments | « src/ia32/ic-ia32.cc ('k') | src/mips/ic-mips.cc » ('j') | src/stub-cache.cc » ('J')
@@ -236,12 +236,15 @@ class CallICBase: public IC {
static void Clear(Address address, Code* target);
- // Platform-specific generation of misses for call and keyed call.
+ // Platform-specific code generation functions used by both call and
+ // keyed call.
static void GenerateMiss(MacroAssembler* masm,
int argc,

Powered by Google App Engine
This is Rietveld 408576698